@@ -1,5 +1,5 @@
 from django.db.models import TextField
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from .validators import validate_comma_separated_emails
 
