@@ -1,4 +1,4 @@
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from django_mail_admin.utils import STATUS
 from django.db import models
 from .outgoing import OutgoingEmail
